{
  "type": "record",
  "Aspect": {
    "name": "proposals"
  },
  "name": "Proposals",
  "namespace": "com.linkedin.pegasus2avro.common",
  "fields": [
    {
      "Searchable": {
        "/*": {
          "addToFilters": true,
          "fieldName": "proposedTags",
          "fieldType": "URN",
          "filterNameOverride": "Proposed Tag"
        }
      },
      "type": [
        "null",
        {
          "type": "array",
          "items": "string"
        }
      ],
      "name": "proposedTags",
      "default": null,
      "doc": "Proposed tags for a given entity",
      "Urn": "Urn",
      "urn_is_array": true
    },
    {
      "Searchable": {
        "/*": {
          "addToFilters": true,
          "fieldName": "proposedGlossaryTerms",
          "fieldType": "URN",
          "filterNameOverride": "Proposed Glossary Term"
        }
      },
      "type": [
        "null",
        {
          "type": "array",
          "items": "string"
        }
      ],
      "name": "proposedGlossaryTerms",
      "default": null,
      "doc": "Proposed glossary terms for a given entity",
      "Urn": "Urn",
      "urn_is_array": true
    }
  ],
  "doc": "Proposals aspect for proposed tags and glossary terms for an entity.\nThese are secondary indices and ActionRequests remain the source of truth."
}